clear; clc; format compact

% Data File: skin.dat
% This data is from Andrews and Herzberg.
% The aetiology of melanoma is complex and may include the influences
% of trauma, heredity and hormonal activity. In particular, exposure
% to solar radiation may be involved in the pathogenesis of melanoma.
% Melanoma is more common in fair-skinned individuals and most frequent
% in skin sites exposed to the sun. In white populations melanoma is
% more common in areas closer to the equator where the intensity of
% solar radiation is higher. Data from various parts of the world suggest
% that the incidence of melanoma is increasing. The data below, giving
% age-adjusted melanoma incidence, are from the Connecticut Tumor Registry
% from 1936-1972. Connecticut has the longest record of state
% population-based cancer statistics in the United States of America.
% The data also includes the sunspot relative number. Houghton, Munster
% and Viola (1978) have shown that the age-adjusted incidence rate for
% malignant melanoma in the state of Connecticut has risen since 1935 and
% that superimposed on the rise are 3-5 year periods in which the rise
% in the rate of incidence is excessive. These periods have a cycle of
% 8-11 years and follow times of maximum sunspot activity. The relationship
% between solar cycles and melanoma supports the hypothesis that melanoma
% is related to sun exposure and provides evidence that solar radiation
% may trigger the development of clinically apparent melanoma. The columns
% are the year, male incidence, total incidence, and sunspot relative
% index. The incidence are rates per 100,000.
%
% Below is the contents of the file skin.dat:
% Year % 1936-1972
% ANNUAL MALE MELANOMA INCIDENCE(AGE-ADJUSTED PER 10**5) CONNECTICUT
% ANNUAL TOTAL MELANOMA INCIDENCE(AGE-ADJUSTED PER 10**5) CONNECTICUT
% ANNUAL SUNSPOT RELATIVE NUMBER

%============= Causality Analysis using PDC ==============================
% In this example, ANNUAL SUNSPOT RELATIVE NUMBER and TOTAL MELANOMA
% INCIDENCE(AGE-ADJUSTED PER 10**5) in the state of CONNECTICUT will be
% considered

disp('======================================================================');
disp('     Andrews and Herzberg''s Sunspot and Melanoma 1936-1972 Data');
disp('                 Sunspot --> Melanoma or other way?');
disp('======================================================================');

flgDataPlot = 1;

% Data set for analysis

x=sunmeladat([4 3]); chLabels={'Sunspot';'Melanoma'};
u = x;
nPoints = length(u);
if flgDataPlot,
   year=sunmeladat(1);  % Year variable
   h1=figure;
   set(h1,'NumberTitle','off','MenuBar','none', ...
      'Name','Andrews & Herzberg''s Sunspot-Melanoma Series (1936-1972)')
   h = subplot(311); plot(year,u(:,1),'o:r'); title('Sunspot series'); grid
   set(h,'XLim', [1935 1975], ...             %'YLim',ylim, ...
      'XTick',[1935:5:1975], ...
      'XTickLabel',[' ';' ';' ';' ';' ';' ';' ';' ';' ']);

   h = subplot(312); plot(year,u(:,2),'.:'); xlabel(''); title('Melanoma series');grid
   set(h,'XLim', [1935 1975], ...             %'YLim',ylim, ...
      'XTick',[1935:5:1975], ...
      'XTickLabel',[' ';' ';' ';' ';' ';' ';' ';' ';' ']);
   h = subplot(313); plot(year,detrend(u(:,2)),'.:'); xlabel('year');
   set(h,'XLim', [1935 1975])
   title('detrended melanoma series')
   grid; hold on; pause(1)

   h2=figure;
   set(h2,'NumberTitle','off','MenuBar','none', ...
      'Name','Andrews & Herzberg''s Sunspot-Melanoma Series (1936-1972)')
   u2=u(:,2); u2=detrend(u2);
   h = subplot(211); plot(year,(u2-mean(u2))/std(u2),'b*:',...
      year,(u(:,1)-mean(u(:,1)))/std(u(:,1)),'ro-');
   set(h,'XLim', [1935 1975])
   title('Melanoma & Sunspot: Standardized series')
   legend('Melanoma','Sunspot');grid

   [uxcorr,lag]=xcorr(u2,u(:,1),'coeff');
   subplot(212); plot(lag,uxcorr,'o--'); xlabel('lag(year)');
   title('Normalized cross-correlation function'); axis([-20 20 -1 1]); grid; hold on
%   tilefigs
end;


%==========================================================================
%             original PDCn estimation and analysis parameters
%==========================================================================

run example_analysis_parameters % Setting default paramaters 

flgDetrend = 1;
flgStandardize = 0;

run example_pre_processing      % Detrending and/or standardization

%corrigido!!!
if flgStandardize,
   for i=1:nChannels, u(i,:)=u(i,:)/std(u(i,:)); end;
   disp('Time series were standardized.');
end;


% 
% figure, plot(u')
% 
% 


run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.

%=======Overriding some default parameters for plotting and analysis=======

metric = 'euc'; % euc  = Euclidian = original PDC;
                % diag = diagonal  = generalized PDC or gPDC;
                % info = informational = iPDC
                
% ---------------Plotting options flag setting-----------------------------
%           [1 2 3 4 5 6 7]
flgPrinting=[1 1 1 2 2 0 1];
%            | | | | | | 7 Spectra(0: w/o SS; 1: Linear; 2: log-scale)
%            | | | | | 6 Coherence
%            | | | | 5 Plot lower confidence limit
%            | | | 4 Plot upper confidence limit
%            | | 3 Significant PDC(w) in red line
%            | 2 Patnaik threshold level in black dashed-line
%            1 PDC in green line
%--------------------------------------------------------------------------

run example_pdc_analysis

%save andrews_herzberg_PDC 

flgColor =[0];
%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;
flgScale = 3;
flgSignifColor = 1;
flgMax ='TCI';
for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
      'Name','Figure 7.7 Sunspot-Melanoma, nonstandardized, PDC')
   [hxlabel hylabel] = xplot(c,flgPrinting,fs,w_max,chLabels,kflgColor, ...
                                              flgScale,flgMax,flgSignifColor);
   xplot_title(alpha,metric);
end;

%==========================================================================
%             Generalized PDC estimation and analysis parameters
%==========================================================================

metric = 'diag'; % euc  = original PDC;
                % diag = generalized PDC or gPDC;
                % info = informational PDC or iPDC
                
run example_pdc_analysis

kflgColor = 0;
flgScale = 1;
flgSignifColor = 1;
%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
h=figure;
set(h,'NumberTitle','off','MenuBar','none', ...
   'Name','Figure 7.8 Sunspot-Melanoma iPDC')
   [hxlabel hylabel] = xplot(c,flgPrinting,fs,w_max,chLabels,kflgColor, ...
                                              flgScale,flgMax,flgSignifColor);
xplot_title(alpha,metric);

disp('%==========================================================================')
disp('            End of Sunspot-Melanoma series analysis example.')
disp('%==========================================================================')